#
# spec file for package python-pyenchant
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyenchant
Version:        3.2.2
Release:        3.2
Summary:        Python bindings for the Enchant spellchecking system
License:        LGPL-2.1-or-later
URL:            https://pyenchant.github.io/pyenchant
Source:         https://github.com/pyenchant/pyenchant/archive/v%{version}.tar.gz#/pyenchant-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
%if 0%{?suse_version} > 1500
BuildRequires:  enchant-2-backend-hunspell
%else
BuildRequires:  enchant
%endif
BuildRequires:  fdupes
BuildRequires:  myspell-en
BuildRequires:  myspell-en_AU
BuildRequires:  myspell-en_US
BuildRequires:  python-rpm-macros
%if 0%{?suse_version} > 1500
Requires:       enchant-2-backend-hunspell
%else
Requires:       enchant
%endif
Provides:       python-enchant
BuildArch:      noarch
%python_subpackages

%description
PyEnchant is a spellchecking library for Python, based on the excellent Enchant library.

%prep
%setup -q -n pyenchant-%{version}
chmod a-x *.txt
# cleanup github tarball
rm -rf website .github archive tools

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%python_exec -c 'import enchant; print(vars(enchant.Dict()))'
ignore=""
%if 0%{suse_version} == 1600
# test_can_use_multiprocessing fails to build in OBS for ALP,
# bsc#1221034
ignore="--ignore tests/test_multiprocessing.py"
%endif
%pytest $ignore

%files %{python_files}
%license LICENSE.txt
%doc README.rst TODO.txt
%{python_sitelib}/enchant
%{python_sitelib}/pyenchant-%{version}.dist-info

%changelog
* Mon Mar 11 2024 Daniel Garcia <daniel.garcia@suse.com>
- Skip problematic multprocessing test for ALP, bsc#1221034
* Sat Sep 30 2023 Ben Greiner <code@bnavigator.de>
- Move to PEP517
- Add sle15_python_module_pythons (for mygnuhealth)
* Wed Dec  1 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.2.2:
  * Add support for Python 3.10
  * Fix ``Dict.__del__`` sometimes raising `TypeError` upon exit.
* Fri Jan 22 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v3.2.0
  * Add support for Python 3.9
  * Add trove classifiers for all supported Python versions
  * Run ``pyupgrade`` across the code base
  * Update documentation about MacPorts
* Sun May 31 2020 Matej Cepl <mcepl@suse.com>
- Update to version 3.1.1:
  - On Windows, set PATH instead of calling SetDllDirectory
    before loading the Enchant C library. This allows PyEnchant to
    co-exist with other libraries in the same program. Fix
    gh#pyenchant/pyenchant#207.
  - Hopefully fix gh#pyenchant/pyenchant#203 as well.
* Thu May 21 2020 Matej Cepl <mcepl@suse.com>
- Update to version 3.1.0:
  - Add enchant.get_user_config_dir()
  - Fix: enchant.get_enchant_version() now returns a str,
    not some bytes
- Skip test test_docstrings (gh#pyenchant/pyenchant#203)
* Fri Mar 20 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 3.0.1
  * Uncouple PyEnchant version from the Enchant version. This release
    should be compatible with Enchant 1.6 to 2.2
  * Fix using PyEnchant with Enchant >= 2.0
  * Add support for pypy3, Python 3.7 and Python 3.8
  * New website, hosted on https://pyenchant.github.io/pyenchant/
  * Add enchant.set_prefix_dir()
  * Drop support for Python2
- Drop obsolete patch enchant2.patch
* Fri Jul 19 2019 Antonio Larrosa <alarrosa@suse.com>
- Modified enchant2.patch so the enchant-2 library is used when both
  enchant 1 and enchant 2 are installed on the system (boo#1141993).
* Tue Jan  8 2019 alarrosa@suse.com
- Use enchant 1 in SLE 15/Leap 15
* Fri Aug 24 2018 tchvatal@suse.com
- Update to 2.0.0:
  * Support for enchant2, py3 fixes
- Add patch to prefer enchant2 when both available:
  * enchant2.patch
* Thu Aug 31 2017 toddrme2178@gmail.com
- update to version 1.6.11
  * No changelog
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Mon May 11 2015 benoit.monin@gmx.fr
- update to  version 1.6.6:
  * compatibility with latest python releases
  * "wheels" replace "eggs" as the binary distribution format of
    choice
  * fix possible text corruption when using SpellChecker with a
    Chunker
- drop pyenchant-drop-bootstrap-distribute.patch: fixed upstream
* Sat Sep 14 2013 os-dev@jacraig.com
- Add pyenchant-drop-bootstrap-distribute.patch: don't use the distribute
  bootstrapping code, just use setuptools.  Fixes build that was broken by the
  attempt to download distribute.
* Fri May  4 2012 toddrme2178@gmail.com
- Add full url to source
- Make python 3 package noarch like the python 2 package
- Fix rpmlint warnings
* Mon Apr 30 2012 toddrme2178@gmail.com
- Add python 3 package
- Clean up python 2 spec file
* Mon Feb 27 2012 cfarrell@suse.com
- license update: LGPL-2.1+
  No reason to believe that the package author restricted licensing to only
  version 2.1 of the LGPL. As such LGPL-2.1+ is the better choice
* Mon Feb 20 2012 saschpe@suse.de
- Spec file cleanup:
  * Simplified macro usage
  * Removed outdated %%clean section
  * Set SPDX-style license
  * No CFLAGS for noarch package
* Fri Apr 15 2011 saschpe@suse.de
- Initial version 1.6.5
- Obsoletes package 'python-enchant'
